/**
 * Options for `formatToCapitalizedd` function.
 */
declare type Options = {
    wordsToKeepLowerCase?: string[];
    wordsToKeepUpperCase?: string[];
    trimTrailingWhiteSpaces?: boolean;
};
/**
 * Capitaliza as palavras de um texto, com exceção das palavras configuradas
 * para serem deixadas em caixa-alta ou em caixa-baixa (menos a primeira palavra
 * que não será caixa-baixa mesmo se configurada como).
 *
 * @example ```js
 * formatToCapitalized('SERVIDOR PÚBLICO MUNICIPAL')
 * //=> 'Servidor Público Municipal'
 *
 * formatToCapitalized('   os PrimEIROS  HOMens da tERra', {
 *   wordsToKeepLowerCase: ['os', 'da']
 * })
 * //=> 'Os Primeiros Homens da Terra'
 *
 * formatToCapitalized('nova tv foi lançada', {
 *   wordsToKeepUpperCase: ['tv']
 * })
 * //=> 'Nova TV Foi Lançada'
 *
 * formatToCapitalized(' com espaços antes e depois ', {
 *   trimTrailingWhiteSpaces: false
 * })
 * //=> ' Com Espaços Antes e Depois '
 * ```
 * @param value - A `string` to capitalize
 */
declare const formatToCapitalized: (value: string, { wordsToKeepLowerCase, wordsToKeepUpperCase, trimTrailingWhiteSpaces, }?: Options) => string;
export default formatToCapitalized;
